/*
 * vi:ts=4:tw=78:shiftwidth=4:expandtab
 * vim600:fdm=marker
 *
 * unicode.h  - This file defines a set of unicode types that can be used
 * safely on several platforms that lacks wchar_t or wstring support.
 * The following types are defined:
 *
 * uchar_t    : a unicode char [default to UCS2, 2 bytes]
 *
 * Copyright (C) 2003 by Zhang Le <ejoy@users.sourceforge.net>
 * Begin       : 08-Aug-2003
 * Last Change : 29-May-2005.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef _UNICODE_H
#define _UNICODE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stddef.h> /* for size_t */

#if defined(__cplusplus)
extern "C" {
#endif

typedef unsigned short uchar_t;
typedef unsigned short uint_t;

#define SIZEOF_UCHAR_T 2

size_t ustrlen(const uchar_t* s);
uchar_t* ustrdup(const uchar_t* s);
uchar_t* ustrcpy(uchar_t* dest, const uchar_t* src);
uchar_t* ustrncpy(uchar_t* dest, const uchar_t *src, size_t count);

#if defined(__cplusplus)
}
#endif
#endif /* ifndef _UNICODE_H */

